@@ -26,7 +26,8 @@ typedef enum {
   CLUTTER_DEBUG_LAYOUT              = 1 << 15,
   CLUTTER_DEBUG_PICK                = 1 << 16,
   CLUTTER_DEBUG_EVENTLOOP           = 1 << 17,
-  CLUTTER_DEBUG_CLIPPING            = 1 << 18
+  CLUTTER_DEBUG_CLIPPING            = 1 << 18,
+  CLUTTER_DEBUG_OOB_TRANSFORMS      = 1 << 19
 } ClutterDebugFlag;
 
 typedef enum {
