@@ -613,9 +613,9 @@
 #define CLUTTER_nacute 0x1f1
 #define CLUTTER_ncaron 0x1f2
 #define CLUTTER_odoubleacute 0x1f5
-#define CLUTTER_udoubleacute 0x1fb
 #define CLUTTER_rcaron 0x1f8
 #define CLUTTER_uring 0x1f9
+#define CLUTTER_udoubleacute 0x1fb
 #define CLUTTER_tcedilla 0x1fe
 #define CLUTTER_abovedot 0x1ff
 #define CLUTTER_Hstroke 0x2a1
@@ -676,32 +676,32 @@
 #define CLUTTER_uogonek 0x3f9
 #define CLUTTER_utilde 0x3fd
 #define CLUTTER_umacron 0x3fe
+#define CLUTTER_Wcircumflex 0x1000174
+#define CLUTTER_wcircumflex 0x1000175
+#define CLUTTER_Ycircumflex 0x1000176
+#define CLUTTER_ycircumflex 0x1000177
 #define CLUTTER_Babovedot 0x1001e02
 #define CLUTTER_babovedot 0x1001e03
 #define CLUTTER_Dabovedot 0x1001e0a
-#define CLUTTER_Wgrave 0x1001e80
-#define CLUTTER_Wacute 0x1001e82
 #define CLUTTER_dabovedot 0x1001e0b
-#define CLUTTER_Ygrave 0x1001ef2
 #define CLUTTER_Fabovedot 0x1001e1e
 #define CLUTTER_fabovedot 0x1001e1f
 #define CLUTTER_Mabovedot 0x1001e40
 #define CLUTTER_mabovedot 0x1001e41
 #define CLUTTER_Pabovedot 0x1001e56
-#define CLUTTER_wgrave 0x1001e81
 #define CLUTTER_pabovedot 0x1001e57
-#define CLUTTER_wacute 0x1001e83
 #define CLUTTER_Sabovedot 0x1001e60
-#define CLUTTER_ygrave 0x1001ef3
+#define CLUTTER_sabovedot 0x1001e61
+#define CLUTTER_Tabovedot 0x1001e6a
+#define CLUTTER_tabovedot 0x1001e6b
+#define CLUTTER_Wgrave 0x1001e80
+#define CLUTTER_wgrave 0x1001e81
+#define CLUTTER_Wacute 0x1001e82
+#define CLUTTER_wacute 0x1001e83
 #define CLUTTER_Wdiaeresis 0x1001e84
 #define CLUTTER_wdiaeresis 0x1001e85
-#define CLUTTER_sabovedot 0x1001e61
-#define CLUTTER_Wcircumflex 0x1000174
-#define CLUTTER_Tabovedot 0x1001e6a
-#define CLUTTER_Ycircumflex 0x1000176
-#define CLUTTER_wcircumflex 0x1000175
-#define CLUTTER_tabovedot 0x1001e6b
-#define CLUTTER_ycircumflex 0x1000177
+#define CLUTTER_Ygrave 0x1001ef2
+#define CLUTTER_ygrave 0x1001ef3
 #define CLUTTER_OE 0x13bc
 #define CLUTTER_oe 0x13bd
 #define CLUTTER_Ydiaeresis 0x13be
@@ -2034,6 +2034,86 @@
 #define CLUTTER_braille_dots_1345678 0x10028fd
 #define CLUTTER_braille_dots_2345678 0x10028fe
 #define CLUTTER_braille_dots_12345678 0x10028ff
+#define CLUTTER_Sinh_ng 0x1000d82
+#define CLUTTER_Sinh_h2 0x1000d83
+#define CLUTTER_Sinh_a 0x1000d85
+#define CLUTTER_Sinh_aa 0x1000d86
+#define CLUTTER_Sinh_ae 0x1000d87
+#define CLUTTER_Sinh_aee 0x1000d88
+#define CLUTTER_Sinh_i 0x1000d89
+#define CLUTTER_Sinh_ii 0x1000d8a
+#define CLUTTER_Sinh_u 0x1000d8b
+#define CLUTTER_Sinh_uu 0x1000d8c
+#define CLUTTER_Sinh_ri 0x1000d8d
+#define CLUTTER_Sinh_rii 0x1000d8e
+#define CLUTTER_Sinh_lu 0x1000d8f
+#define CLUTTER_Sinh_luu 0x1000d90
+#define CLUTTER_Sinh_e 0x1000d91
+#define CLUTTER_Sinh_ee 0x1000d92
+#define CLUTTER_Sinh_ai 0x1000d93
+#define CLUTTER_Sinh_o 0x1000d94
+#define CLUTTER_Sinh_oo 0x1000d95
+#define CLUTTER_Sinh_au 0x1000d96
+#define CLUTTER_Sinh_ka 0x1000d9a
+#define CLUTTER_Sinh_kha 0x1000d9b
+#define CLUTTER_Sinh_ga 0x1000d9c
+#define CLUTTER_Sinh_gha 0x1000d9d
+#define CLUTTER_Sinh_ng2 0x1000d9e
+#define CLUTTER_Sinh_nga 0x1000d9f
+#define CLUTTER_Sinh_ca 0x1000da0
+#define CLUTTER_Sinh_cha 0x1000da1
+#define CLUTTER_Sinh_ja 0x1000da2
+#define CLUTTER_Sinh_jha 0x1000da3
+#define CLUTTER_Sinh_nya 0x1000da4
+#define CLUTTER_Sinh_jnya 0x1000da5
+#define CLUTTER_Sinh_nja 0x1000da6
+#define CLUTTER_Sinh_tta 0x1000da7
+#define CLUTTER_Sinh_ttha 0x1000da8
+#define CLUTTER_Sinh_dda 0x1000da9
+#define CLUTTER_Sinh_ddha 0x1000daa
+#define CLUTTER_Sinh_nna 0x1000dab
+#define CLUTTER_Sinh_ndda 0x1000dac
+#define CLUTTER_Sinh_tha 0x1000dad
+#define CLUTTER_Sinh_thha 0x1000dae
+#define CLUTTER_Sinh_dha 0x1000daf
+#define CLUTTER_Sinh_dhha 0x1000db0
+#define CLUTTER_Sinh_na 0x1000db1
+#define CLUTTER_Sinh_ndha 0x1000db3
+#define CLUTTER_Sinh_pa 0x1000db4
+#define CLUTTER_Sinh_pha 0x1000db5
+#define CLUTTER_Sinh_ba 0x1000db6
+#define CLUTTER_Sinh_bha 0x1000db7
+#define CLUTTER_Sinh_ma 0x1000db8
+#define CLUTTER_Sinh_mba 0x1000db9
+#define CLUTTER_Sinh_ya 0x1000dba
+#define CLUTTER_Sinh_ra 0x1000dbb
+#define CLUTTER_Sinh_la 0x1000dbd
+#define CLUTTER_Sinh_va 0x1000dc0
+#define CLUTTER_Sinh_sha 0x1000dc1
+#define CLUTTER_Sinh_ssha 0x1000dc2
+#define CLUTTER_Sinh_sa 0x1000dc3
+#define CLUTTER_Sinh_ha 0x1000dc4
+#define CLUTTER_Sinh_lla 0x1000dc5
+#define CLUTTER_Sinh_fa 0x1000dc6
+#define CLUTTER_Sinh_al 0x1000dca
+#define CLUTTER_Sinh_aa2 0x1000dcf
+#define CLUTTER_Sinh_ae2 0x1000dd0
+#define CLUTTER_Sinh_aee2 0x1000dd1
+#define CLUTTER_Sinh_i2 0x1000dd2
+#define CLUTTER_Sinh_ii2 0x1000dd3
+#define CLUTTER_Sinh_u2 0x1000dd4
+#define CLUTTER_Sinh_uu2 0x1000dd6
+#define CLUTTER_Sinh_ru2 0x1000dd8
+#define CLUTTER_Sinh_e2 0x1000dd9
+#define CLUTTER_Sinh_ee2 0x1000dda
+#define CLUTTER_Sinh_ai2 0x1000ddb
+#define CLUTTER_Sinh_o2 0x1000ddc
+#define CLUTTER_Sinh_oo2 0x1000ddd
+#define CLUTTER_Sinh_au2 0x1000dde
+#define CLUTTER_Sinh_lu2 0x1000ddf
+#define CLUTTER_Sinh_ruu2 0x1000df2
+#define CLUTTER_Sinh_luu2 0x1000df3
+#define CLUTTER_Sinh_kunddaliya 0x1000df4
 #define CLUTTER_ModeLock 0x1008ff01
 #define CLUTTER_MonBrightnessUp 0x1008ff02
 #define CLUTTER_MonBrightnessDown 0x1008ff03
