@@ -530,18 +530,10 @@ update_fbo (ClutterActor *self)
       if ((source_parent = clutter_actor_get_parent (priv->fbo_source)))
         {
           CoglMatrix modelview;
-
-          /* NB: _clutter_actor_apply_modelview_transform_recursive
-           * will never include the transformation between stage
-           * coordinates and OpenGL window coordinates, we have to
-           * explicitly use the stage->apply_transform to get that...
-           */
-
           cogl_matrix_init_identity (&modelview);
-          _clutter_actor_apply_modelview_transform (stage, &modelview);
-          _clutter_actor_apply_modelview_transform_recursive (source_parent,
-                                                              NULL,
-                                                              &modelview);
+          _clutter_actor_apply_relative_transformation_matrix (source_parent,
+                                                               NULL,
+                                                               &modelview);
           cogl_set_modelview_matrix (&modelview);
         }
     }
@@ -1223,10 +1215,10 @@ clutter_texture_class_init (ClutterTextureClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterTextureClass, load_finished),
 		  NULL, NULL,
-		  _clutter_marshal_VOID__POINTER,
+		  _clutter_marshal_VOID__BOXED,
 		  G_TYPE_NONE,
 		  1,
-                  G_TYPE_POINTER);
+                  G_TYPE_ERROR);
 }
 
 static ClutterScriptableIface *parent_scriptable_iface = NULL;
@@ -1562,7 +1554,7 @@ clutter_texture_set_from_data (ClutterTexture     *texture,
 
       g_set_error (&inner_error, CLUTTER_TEXTURE_ERROR,
                    CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-                   "Failed to create Cogl texture");
+                   _("Failed to load the image data"));
 
       g_signal_emit (texture, texture_signals[LOAD_FINISHED], 0, inner_error);
 
@@ -1586,10 +1578,53 @@ clutter_texture_set_from_data (ClutterTexture     *texture,
   return TRUE;
 }
 
+static inline gboolean
+get_pixel_format_from_texture_flags (gint                 bpp,
+                                     gboolean             has_alpha,
+                                     ClutterTextureFlags  flags,
+                                     CoglPixelFormat     *source_format)
+{
+  /* Convert the flags to a CoglPixelFormat */
+  if (has_alpha)
+    {
+      if (G_UNLIKELY (bpp != 4))
+	{
+          g_warning ("Unsupported bits per pixel value '%d': "
+                     "Clutter supports only a  value of 4 "
+                     "for RGBA data",
+                     bpp);
+	  return FALSE;
+	}
+
+      *source_format = COGL_PIXEL_FORMAT_RGBA_8888;
+    }
+  else
+    {
+      if (G_UNLIKELY (bpp != 3))
+	{
+          g_warning ("Unsupported bits per pixel value '%d': "
+                     "Clutter supports only a BPP value of 3 "
+                     "for RGB data",
+                     bpp);
+	  return FALSE;
+	}
+
+      *source_format = COGL_PIXEL_FORMAT_RGB_888;
+    }
+
+  if ((flags & CLUTTER_TEXTURE_RGB_FLAG_BGR))
+    *source_format |= COGL_BGR_BIT;
+
+  if ((flags & CLUTTER_TEXTURE_RGB_FLAG_PREMULT))
+    *source_format |= COGL_PREMULT_BIT;
+
+  return TRUE;
+}
+
 /**
  * clutter_texture_set_from_rgb_data:
  * @texture: A #ClutterTexture
- * @data: Image data in RGBA type colorspace.
+ * @data: (array): Image data in RGBA type colorspace.
  * @has_alpha: Set to TRUE if image data has an alpha channel.
  * @width: Width in pixels of image data.
  * @height: Height in pixels of image data
@@ -1620,42 +1655,13 @@ clutter_texture_set_from_rgb_data (ClutterTexture       *texture,
 
   g_return_val_if_fail (CLUTTER_IS_TEXTURE (texture), FALSE);
 
-  /* Convert the flags to a CoglPixelFormat */
-  if (has_alpha)
+  if (!get_pixel_format_from_texture_flags (bpp,
+                                            has_alpha,
+                                            flags,
+                                            &source_format))
     {
-      if (bpp != 4)
-	{
-	  g_set_error (error, CLUTTER_TEXTURE_ERROR,
-		       CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		       "Unsupported bits per pixel value '%d': "
-                       "Clutter supports only a BPP value of 4 "
-                       "for RGBA data",
-                       bpp);
-	  return FALSE;
-	}
-
-      source_format = COGL_PIXEL_FORMAT_RGBA_8888;
+      return FALSE;
     }
-  else
-    {
-      if (bpp != 3)
-	{
-	  g_set_error (error, CLUTTER_TEXTURE_ERROR,
-		       CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		       "Unsupported bits per pixel value '%d': "
-                       "Clutter supports only a BPP value of 3 "
-                       "for RGB data",
-                       bpp);
-	  return FALSE;
-	}
-
-      source_format = COGL_PIXEL_FORMAT_RGB_888;
-    }
-
-  if ((flags & CLUTTER_TEXTURE_RGB_FLAG_BGR))
-    source_format |= COGL_BGR_BIT;
-  if ((flags & CLUTTER_TEXTURE_RGB_FLAG_PREMULT))
-    source_format |= COGL_PREMULT_BIT;
 
   return clutter_texture_set_from_data (texture, data,
 					source_format,
@@ -1667,7 +1673,7 @@ clutter_texture_set_from_rgb_data (ClutterTexture       *texture,
 /**
  * clutter_texture_set_from_yuv_data:
  * @texture: A #ClutterTexture
- * @data: Image data in YUV type colorspace.
+ * @data: (array): Image data in YUV type colorspace.
  * @width: Width in pixels of image data.
  * @height: Height in pixels of image data
  * @flags: #ClutterTextureFlags
@@ -1694,7 +1700,7 @@ clutter_texture_set_from_yuv_data (ClutterTexture     *texture,
     {
       g_set_error (error, CLUTTER_TEXTURE_ERROR,
                    CLUTTER_TEXTURE_ERROR_NO_YUV,
-                   "YUV textures are not supported");
+                   _("YUV textures are not supported"));
       return FALSE;
     }
 
@@ -1703,7 +1709,7 @@ clutter_texture_set_from_yuv_data (ClutterTexture     *texture,
     {
       g_set_error (error, CLUTTER_TEXTURE_ERROR,
 		   CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		   "YUV2 textues are not supported");
+		   _("YUV2 textues are not supported"));
       return FALSE;
     }
 
@@ -1958,7 +1964,7 @@ clutter_texture_async_load (ClutterTexture *self,
     {
       g_set_error (error, CLUTTER_TEXTURE_ERROR,
 		   CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		   "Failed to create Cogl texture");
+                   _("Failed to load the image data"));
       return FALSE;
     }
   else
@@ -2053,7 +2059,7 @@ clutter_texture_set_from_file (ClutterTexture *texture,
     {
       g_set_error (&internal_error, CLUTTER_TEXTURE_ERROR,
                    CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		   "Failed to create Cogl texture");
+		   _("Failed to load the image data"));
     }
 
   if (internal_error != NULL)
@@ -2265,7 +2271,7 @@ clutter_texture_get_base_size (ClutterTexture *texture,
 /**
  * clutter_texture_set_area_from_rgb_data:
  * @texture: A #ClutterTexture
- * @data: Image data in RGB type colorspace.
+ * @data: (array): Image data in RGB type colorspace.
  * @has_alpha: Set to TRUE if image data has an alpha channel.
  * @x: X coordinate of upper left corner of region to update.
  * @y: Y coordinate of upper left corner of region to update.
@@ -2299,36 +2305,11 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
   CoglPixelFormat source_format;
   CoglHandle cogl_texture;
 
-  if (has_alpha)
+  if (!get_pixel_format_from_texture_flags (bpp, has_alpha, flags,
+                                            &source_format))
     {
-      if (bpp != 4)
-	{
-	  g_set_error (error, CLUTTER_TEXTURE_ERROR,
-		       CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		       "Unsupported BPP");
-	  return FALSE;
-	}
-
-      source_format = COGL_PIXEL_FORMAT_RGBA_8888;
+      return FALSE;
     }
-  else
-    {
-      if (bpp != 3)
-	{
-	  g_set_error (error, CLUTTER_TEXTURE_ERROR,
-		       CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		       "Unsupported BPP");
-	  return FALSE;
-	}
-
-      source_format = COGL_PIXEL_FORMAT_RGB_888;
-    }
-
-  if ((flags & CLUTTER_TEXTURE_RGB_FLAG_BGR))
-    source_format |= COGL_BGR_BIT;
-
-  if ((flags & CLUTTER_TEXTURE_RGB_FLAG_PREMULT))
-    source_format |= COGL_PREMULT_BIT;
 
   /* attempt to realize ... */
   if (!CLUTTER_ACTOR_IS_REALIZED (texture) &&
@@ -2344,9 +2325,8 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
   cogl_texture = clutter_texture_get_cogl_texture (texture);
   if (cogl_texture == COGL_INVALID_HANDLE)
     {
-      g_set_error (error, CLUTTER_TEXTURE_ERROR,
-		   CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		   "Failed to realize actor");
+      g_warning ("Failed to realize actor '%s'",
+                 _clutter_actor_get_debug_name (CLUTTER_ACTOR (texture)));
       return FALSE;
     }
 
@@ -2360,7 +2340,7 @@ clutter_texture_set_area_from_rgb_data (ClutterTexture     *texture,
     {
       g_set_error (error, CLUTTER_TEXTURE_ERROR,
 		   CLUTTER_TEXTURE_ERROR_BAD_FORMAT,
-		   "Failed to upload Cogl texture data");
+		   _("Failed to load the image data"));
       return FALSE;
     }
 
@@ -2549,6 +2529,10 @@ fbo_source_queue_relayout_cb (ClutterActor *source,
  *
  * Return value: A newly created #ClutterTexture object, or %NULL on failure.
  *
+ * Deprecated: 1.8: Use the #ClutterOffscreenEffect and #ClutterShaderEffect
+ *   directly on the intended #ClutterActor to replace the functionality of
+ *   this function.
+ *
  * Since: 0.6
  */
 ClutterActor *
