@@ -332,9 +332,9 @@ clutter_timeline_class_init (ClutterTimelineClass *klass)
   object_class->finalize     = clutter_timeline_finalize;
   object_class->set_property = clutter_timeline_set_property;
   object_class->get_property = clutter_timeline_get_property;
-  _clutter_object_class_install_properties (object_class,
-                                            PROP_LAST,
-                                            obj_props);
+  g_object_class_install_properties (object_class,
+                                     PROP_LAST,
+                                     obj_props);
 
   /**
    * ClutterTimeline::new-frame:
@@ -550,8 +550,10 @@ emit_frame_signal (ClutterTimeline *timeline)
 {
   ClutterTimelinePrivate *priv = timeline->priv;
 
-  g_signal_emit (timeline, timeline_signals[NEW_FRAME], 0,
-                 priv->elapsed_time);
+  /* see bug https://bugzilla.gnome.org/show_bug.cgi?id=654066 */
+  gint elapsed = (gint) priv->elapsed_time;
+
+  g_signal_emit (timeline, timeline_signals[NEW_FRAME], 0, elapsed);
 }
 
 static gboolean
@@ -691,7 +693,7 @@ clutter_timeline_do_frame (ClutterTimeline *timeline)
           else
             priv->direction = CLUTTER_TIMELINE_FORWARD;
 
-          _clutter_notify_by_pspec (G_OBJECT (timeline),
+          g_object_notify_by_pspec (G_OBJECT (timeline),
                                     obj_props[PROP_DIRECTION]);
         }
 
@@ -851,7 +853,7 @@ clutter_timeline_set_loop (ClutterTimeline *timeline,
     {
       timeline->priv->loop = loop;
 
-      _clutter_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_LOOP]);
+      g_object_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_LOOP]);
     }
 }
 
@@ -1077,7 +1079,7 @@ clutter_timeline_set_delay (ClutterTimeline *timeline,
   if (priv->delay != msecs)
     {
       priv->delay = msecs;
-      _clutter_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_DELAY]);
+      g_object_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_DELAY]);
     }
 }
 
@@ -1129,7 +1131,7 @@ clutter_timeline_set_duration (ClutterTimeline *timeline,
     {
       priv->duration = msecs;
 
-      _clutter_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_DURATION]);
+      g_object_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_DURATION]);
     }
 }
 
@@ -1202,7 +1204,7 @@ clutter_timeline_set_direction (ClutterTimeline          *timeline,
       if (priv->elapsed_time == 0)
         priv->elapsed_time = priv->duration;
 
-      _clutter_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_DIRECTION]);
+      g_object_notify_by_pspec (G_OBJECT (timeline), obj_props[PROP_DIRECTION]);
     }
 }
 
@@ -1376,7 +1378,7 @@ collect_markers (const gchar *key,
  * @msecs: the time to check, or -1
  * @n_markers: the number of markers returned
  *
- * Retrieves the list of markers at time @msecs. If @frame_num is a
+ * Retrieves the list of markers at time @msecs. If @msecs is a
  * negative integer, all the markers attached to @timeline will be
  * returned.
  *
@@ -1553,7 +1555,7 @@ clutter_timeline_has_marker (ClutterTimeline *timeline,
  * Sets whether @timeline should reverse the direction after the
  * emission of the #ClutterTimeline::completed signal.
  *
- * Setting the #ClutterTimeline:reverse property to %TRUE is the
+ * Setting the #ClutterTimeline:auto-reverse property to %TRUE is the
  * equivalent of connecting a callback to the #ClutterTimeline::completed
  * signal and changing the direction of the timeline from that callback;
  * for instance, this code:
@@ -1605,7 +1607,7 @@ clutter_timeline_set_auto_reverse (ClutterTimeline *timeline,
     {
       priv->auto_reverse = reverse;
 
-      _clutter_notify_by_pspec (G_OBJECT (timeline),
+      g_object_notify_by_pspec (G_OBJECT (timeline),
                                 obj_props[PROP_AUTO_REVERSE]);
     }
 }
