@@ -23,8 +23,10 @@
 #include "config.h"
 
 #include "clutter-osx.h"
+
 #include "clutter-backend-osx.h"
 #include "clutter-device-manager-osx.h"
+#include "clutter-shader.h"
 #include "clutter-stage-osx.h"
 
 #include "clutter-debug.h"
@@ -76,13 +78,13 @@ clutter_backend_osx_create_stage (ClutterBackend  *backend,
 {
   ClutterStageWindow *impl;
 
-  CLUTTER_NOTE (BACKEND, "create_stage: wrapper=%p", wrapper);
-
   CLUTTER_OSX_POOL_ALLOC();
 
   impl = _clutter_stage_osx_new (backend, wrapper);
 
-  CLUTTER_NOTE (BACKEND, "create_stage: impl=%p", impl);
+  CLUTTER_NOTE (BACKEND, "create_stage: wrapper=%p - impl=%p",
+                wrapper,
+                impl);
 
   CLUTTER_OSX_POOL_RELEASE();
 
@@ -129,11 +131,13 @@ clutter_backend_osx_create_context (ClutterBackend  *backend,
                                     GError         **error)
 {
   ClutterBackendOSX *backend_osx = CLUTTER_BACKEND_OSX (backend);
+
   CLUTTER_OSX_POOL_ALLOC();
-  if ( backend_osx->context == nil)
+
+  if (backend_osx->context == nil)
     {
-      /* Allocate ourselves a GL context. Since we're supposed to have only one per
-       * backend we can just as well create it now.
+      /* Allocate ourselves a GL context. Since we're supposed to have
+       * only one per backend we can just as well create it now.
        */
       NSOpenGLPixelFormatAttribute attrs[] = {
         NSOpenGLPFADoubleBuffer,
@@ -141,21 +145,26 @@ clutter_backend_osx_create_context (ClutterBackend  *backend,
         NSOpenGLPFAStencilSize, 8,
         0
       };
-      
-      backend_osx->pixel_format = [[NSOpenGLPixelFormat alloc] initWithAttributes:attrs];
-      backend_osx->context = [[NSOpenGLContext alloc]
-                              initWithFormat: backend_osx->pixel_format
-                              shareContext: nil];
-      /* Enable vblank sync - http://developer.apple.com/qa/qa2007/qa1521.html */
+
 #ifdef MAC_OS_X_VERSION_10_5
       const int sw = 1;
 #else
       const long sw = 1;
 #endif
+
+      backend_osx->pixel_format = [[NSOpenGLPixelFormat alloc] initWithAttributes:attrs];
+
+      backend_osx->context = [[NSOpenGLContext alloc] initWithFormat: backend_osx->pixel_format
+                                                        shareContext: nil];
+
+      /* Enable vblank sync - http://developer.apple.com/qa/qa2007/qa1521.html */
       [backend_osx->context setValues:&sw forParameter: NSOpenGLCPSwapInterval];
+
+      CLUTTER_NOTE (BACKEND, "Context was created");
     }
+
   [backend_osx->context makeCurrentContext];
-  CLUTTER_NOTE (BACKEND, "Context was created");
+
   CLUTTER_OSX_POOL_RELEASE();
 
   return TRUE;
@@ -167,10 +176,10 @@ clutter_backend_osx_ensure_context (ClutterBackend *backend,
 {
   ClutterBackendOSX *backend_osx = CLUTTER_BACKEND_OSX (backend);
 
-  CLUTTER_NOTE (BACKEND, "ensure_context: wrapper=%p", wrapper);
-
   CLUTTER_OSX_POOL_ALLOC();
 
+  CLUTTER_NOTE (BACKEND, "ensure_context: wrapper=%p", wrapper);
+
   if (wrapper)
     {
       ClutterStageWindow *impl = _clutter_stage_get_window (wrapper);
@@ -196,13 +205,14 @@ clutter_backend_osx_ensure_context (ClutterBackend *backend,
 static void
 clutter_backend_osx_init (ClutterBackendOSX *backend_osx)
 {
+  const ProcessSerialNumber psn = { 0, kCurrentProcess };
+
   backend_osx->context = nil;
   backend_osx->pixel_format = nil;
 
-/* Bring our app to foreground, background apps don't appear in dock or
+  /* Bring our app to foreground, background apps don't appear in dock or
    * accept keyboard focus.
    */
-  const ProcessSerialNumber psn = { 0, kCurrentProcess };
   TransformProcessType (&psn, kProcessTransformToForegroundApplication);
 
   /* Also raise our app to front, otherwise our window will remain under the
