@@ -157,8 +157,8 @@ _create_button (const gchar *text)
 
   label = clutter_text_new_full ("Sans Bold 32px",
                                  text, &color_label);
-  clutter_group_add (CLUTTER_GROUP (button), rectangle);
-  clutter_group_add (CLUTTER_GROUP (button), label);
+  clutter_container_add_actor (CLUTTER_CONTAINER (button), rectangle);
+  clutter_container_add_actor (CLUTTER_CONTAINER (button), label);
   clutter_actor_set_reactive (button, TRUE);
 
   return button;
@@ -180,7 +180,7 @@ make_ui (ClutterActor *stage)
   text_actor = clutter_text_new_full ("Sans Bold 32px",
                                       "Lorem ipsum dolor sit amet",
                                       &color_text);
-  clutter_group_add (CLUTTER_GROUP (stage), text_actor);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), text_actor);
 
   /* text_editable */
   text_editable_actor = clutter_text_new_full ("Sans Bold 32px",
@@ -197,7 +197,7 @@ make_ui (ClutterActor *stage)
   clutter_actor_grab_key_focus (text_editable_actor);
   clutter_actor_set_reactive (text_editable_actor, TRUE);
 
-  clutter_group_add (CLUTTER_GROUP (stage), text_editable_actor);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), text_editable_actor);
   g_signal_connect (text_editable_actor, "activate",
                     G_CALLBACK (activate_cb), NULL);
 
@@ -208,7 +208,7 @@ make_ui (ClutterActor *stage)
   g_signal_connect_after (button, "button-press-event",
                           G_CALLBACK (set_text_press_cb), NULL);
 
-  clutter_group_add (CLUTTER_GROUP (stage), button);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), button);
 
   button = _create_button ("Delete");
   clutter_actor_set_position (button, 100, 250);
@@ -216,7 +216,7 @@ make_ui (ClutterActor *stage)
   g_signal_connect_after (button, "button-press-event",
                           G_CALLBACK (delete_text_press_cb), NULL);
 
-  clutter_group_add (CLUTTER_GROUP (stage), button);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), button);
 
   button = _create_button ("Insert");
   clutter_actor_set_position (button, 100, 300);
@@ -224,7 +224,7 @@ make_ui (ClutterActor *stage)
   g_signal_connect_after (button, "button-press-event",
                           G_CALLBACK (insert_text_press_cb), NULL);
 
-  clutter_group_add (CLUTTER_GROUP (stage), button);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), button);
 
   button = _create_button ("Activate/Deactivate");
   clutter_actor_set_position (button, 100, 350);
@@ -232,7 +232,7 @@ make_ui (ClutterActor *stage)
   g_signal_connect_after (button, "button-press-event",
                           G_CALLBACK (activate_deactivate_press_cb), NULL);
 
-  clutter_group_add (CLUTTER_GROUP (stage), button);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), button);
 
   button = _create_button ("Cursor position");
   clutter_actor_set_position (button, 100, 450);
@@ -240,7 +240,7 @@ make_ui (ClutterActor *stage)
   g_signal_connect_after (button, "button-press-event",
                           G_CALLBACK (print_cursor_position_press_cb), NULL);
 
-  clutter_group_add (CLUTTER_GROUP (stage), button);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), button);
 
 }
 
