@@ -73,12 +73,12 @@ make_ui (ClutterActor *stage)
   full_entry = clutter_group_new ();
   clutter_actor_set_position (full_entry, 0, 50);
   clutter_actor_set_size (full_entry, 100, 75);
-  clutter_group_add (CLUTTER_GROUP (full_entry), label);
-  clutter_group_add (CLUTTER_GROUP (full_entry), editable);
-  clutter_group_add (CLUTTER_GROUP (full_entry), rectangle);
+  clutter_container_add_actor (CLUTTER_CONTAINER (full_entry), label);
+  clutter_container_add_actor (CLUTTER_CONTAINER (full_entry), editable);
+  clutter_container_add_actor (CLUTTER_CONTAINER (full_entry), rectangle);
   clutter_actor_show_all (full_entry);
   clutter_actor_set_scale (full_entry, 2, 1);
-  clutter_group_add (CLUTTER_GROUP (stage), full_entry);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), full_entry);
 
   /* Cloning! */
   cloned_entry = clutter_clone_new (full_entry);
@@ -87,7 +87,7 @@ make_ui (ClutterActor *stage)
   clutter_actor_show_all (cloned_entry);
   clutter_actor_set_reactive (cloned_entry, TRUE);
 
-  clutter_group_add (CLUTTER_GROUP (stage), cloned_entry);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), cloned_entry);
 }
 
 int
