@@ -2,8 +2,6 @@
 
 BINARY=$1
 shift
-XML=$1
-shift
 
 TMP=`./$BINARY -l -m thorough | grep '^/' | sed -e s/_/-/g`
 for i in $TMP
@@ -11,4 +9,4 @@ do
   TESTS="$TESTS wrappers/`basename $i`"
 done
 
-exec gtester -o=$XML "$@" $TESTS
+exec gtester "$@" $TESTS
