@@ -19,7 +19,7 @@ static gboolean press_event (ClutterActor *actor,
                              gpointer      user_data)
 {
   ClutterState *state = CLUTTER_STATE (user_data);
-  clutter_state_change (state, "right", TRUE);
+  clutter_state_set_state (state, "right");
   return TRUE;
 }
 
@@ -28,7 +28,7 @@ static gboolean release_event (ClutterActor *actor,
                                gpointer      user_data)
 {
   ClutterState *state = CLUTTER_STATE (user_data);
-  clutter_state_change (state, "active", TRUE);
+  clutter_state_set_state (state, "active");
   return TRUE;
 }
 
@@ -37,7 +37,7 @@ static gboolean enter_event (ClutterActor *actor,
                              gpointer      user_data)
 {
   ClutterState *state = CLUTTER_STATE (user_data);
-  clutter_state_change (state, "hover", TRUE);
+  clutter_state_set_state (state, "hover");
   return TRUE;
 }
 
@@ -46,7 +46,7 @@ static gboolean leave_event (ClutterActor *actor,
                              gpointer      user_data)
 {
   ClutterState *state = CLUTTER_STATE (user_data);
-  clutter_state_change (state, "normal", TRUE);
+  clutter_state_set_state (state, "normal");
   return TRUE;
 }
 
@@ -54,12 +54,12 @@ static void completed (ClutterState *state,
                        gpointer      data)
 {
   g_print ("Completed transitioning to state: %s\n",
-           clutter_state_get_target_state (state));
+           clutter_state_get_state (state));
 
-  if (g_str_equal (clutter_state_get_target_state (state), "right"))
+  if (g_str_equal (clutter_state_get_state (state), "right"))
     {
       /* skip straight to left state when reaching right */
-      clutter_state_change (state, "left", FALSE);
+      clutter_state_warp_to_state (state, "left");
     }
 }
 
@@ -96,7 +96,8 @@ test_state_main (gint    argc,
   ClutterActor *stage;
   ClutterState *layout_state;
   gint i;
-  clutter_init (&argc, &argv);
+  if (clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+    return 1;
 
   stage = clutter_stage_get_default ();
   layout_state = clutter_state_new ();
@@ -121,6 +122,8 @@ test_state_main (gint    argc,
       clutter_container_add_actor (CLUTTER_CONTAINER (stage), actor);
       clutter_actor_set_position (actor, 320.0, 240.0);
       clutter_actor_set_reactive (actor, TRUE);
+      clutter_actor_add_effect_with_name (actor, "fade",
+                                          clutter_desaturate_effect_new (0.0));
 
 
       clutter_state_set (layout_state, NULL, "active",
@@ -161,10 +164,12 @@ test_state_main (gint    argc,
       clutter_state_set (a_state, NULL, "normal",
                          actor, "opacity", CLUTTER_LINEAR, 0x77,
                          actor, "rotation-angle-z", CLUTTER_LINEAR, 0.0,
+                         actor, "@effects.fade.factor", CLUTTER_LINEAR, 0.0,
                          NULL);
       clutter_state_set (a_state, NULL, "hover",
                          actor, "opacity", CLUTTER_LINEAR, 0xff,
                          actor, "rotation-angle-z", CLUTTER_LINEAR, 10.0,
+                         actor, "@effects.fade.factor", CLUTTER_LINEAR, 1.0,
                          NULL);
       clutter_actor_set_opacity (actor, 0x77);
 
@@ -177,8 +182,9 @@ test_state_main (gint    argc,
   g_signal_connect (layout_state, "completed", G_CALLBACK (completed), NULL);
 
   clutter_actor_show (stage);
-  clutter_state_change (layout_state, "left", FALSE);
-  clutter_state_change (layout_state, "active", TRUE);
+
+  clutter_state_warp_to_state (layout_state, "left");
+  clutter_state_set_state (layout_state, "active");
 
   clutter_main ();
   g_object_unref (layout_state);
